@@ -421,8 +421,9 @@ void warn_what_will_be_done (char * file_name, struct fsck_data * data)
 	(data->log == stdout) ? "stdout" : 
 	(data->log_file_name ? data->log_file_name : "fsck.run"));
     
-    if (!(data->options & OPT_YES) && !user_confirmed (warn_to, "\nDo you want to "
-	"run this program?[N/Yes] (note need to type Yes if you do):", "Yes\n"))
+    if (!(data->options & OPT_YES) && !(data->options & OPT_SILENT) &&
+	!user_confirmed (warn_to, "\nDo you want to run this program?[N/Yes] "
+	"(note need to type Yes if you do):", "Yes\n"))
 	exit (EXIT_USER);
 }
 
@@ -751,11 +752,8 @@ static void reiserfsck_replay_journal (reiserfs_filsys_t * fs) {
 
 static int the_end (reiserfs_filsys_t * fs)
 {
-    struct reiserfs_super_block * sb;
     int ret = EXIT_FIXED;
 
-    sb = fs->fs_ondisk_sb;
-
     /* put bitmap and objectid map on place */
     reiserfs_delete_bitmap (fs->fs_bitmap2);
     fs->fs_bitmap2 = fsck_new_bitmap (fs);
@@ -782,8 +780,8 @@ static int the_end (reiserfs_filsys_t * fs)
     fsck_progress ("Syncing..");
     fs->fs_dirt = 1;
     clean_after_dma_check(fs->fs_dev, &dma_info);
-    reiserfs_close (fs);
     fsck_progress ("finished\n");
+    reiserfs_close (fs);
 
     return ret;
 }
@@ -935,12 +933,12 @@ static void clean_attributes (reiserfs_filsys_t * fs) {
     do_clean_attributes (fs);
 
     clean_after_dma_check(fs->fs_dev, &dma_info);
-    reiserfs_close (fs);
-    close_rollback_file ();
 
     fsck_progress ("###########\n"
 		   "reiserfsck finished at %s"
 		   "###########\n", ctime (&t));
+    reiserfs_close (fs);
+    close_rollback_file ();
 
     exit (EXIT_FIXED);
 
@@ -967,7 +965,7 @@ static int reiserfs_check_auto_state(reiserfs_filsys_t *fs)
 	}
 
 	if (interval != UINT_MAX && now > lastcheck + interval) {
-		fprintf(stderr, "File system hasn't been checked in %u days. "
+		fprintf(stderr, "File system hasn't been checked in %lu days. "
 		        "Checking now.\n", (now - lastcheck) / (60*60*24));
 		return 1;
 	}
@@ -1171,8 +1169,6 @@ static void check_fs (reiserfs_filsys_t * fs)
         
     id_map_free(proper_id_map (fs));
     clean_after_dma_check(fs->fs_dev, &dma_info);
-    reiserfs_close (fs);
-    close_rollback_file ();
     
     //clear_relocated_list();    
     
@@ -1181,6 +1177,8 @@ static void check_fs (reiserfs_filsys_t * fs)
 		   "reiserfsck finished at %s"
 		   "###########\n", ctime (&t));
 
+    reiserfs_close (fs);
+    close_rollback_file ();
     exit(retval);
 }
 
