@@ -534,7 +534,9 @@ static int do_rollback = 0;
 static char * rollback_data;
 static int rollback_blocksize;
 
-void init_rollback_file (char * rollback_file, int *blocksize, FILE * log) {
+void init_rollback_file (char * rollback_file, unsigned int *blocksize,
+			 FILE * log)
+{
     char * string;
     struct stat buf;
     
@@ -658,7 +660,7 @@ void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
     int b_dev;
     int n_dev = 0;
     int n_journal_dev = 0;
-    unsigned long total, done = 0;
+    unsigned long done = 0;
 
     if (fd_device == 0) {
         fprintf(stderr, "rollback: unspecified device, exit\n");
@@ -688,8 +690,6 @@ void do_fsck_rollback (int fd_device, int fd_journal_device, FILE * progress) {
     
     fread (&rollback_blocks_number, sizeof (rollback_blocks_number), 1, s_rollback_file);
 
-    total = rollback_blocks_number;
-    
     while (1) {
         print_how_far (progress, &done, rollback_blocks_number, 1, 0/*not quiet*/);
 	
